@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.016-3-g5340f8b
+package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.017-8-g3e0dabc
 # ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use Moose;
 use MooseX::Types;
@@ -24,40 +24,74 @@ use Scalar::Util 'blessed';
 use namespace::autoclean;
 
 has mb_version => (
-    is  => 'ro', isa => 'Str',
+    is => 'ro', isa => 'Str',
     # <mst> 0.28 is IIRC when install_base changed incompatibly
     default => '0.28',
 );
 
 has mbt_version => (
-    is  => 'ro', isa => 'Str',
+    is => 'ro', isa => 'Str',
+);
+
+has _extra_args => (
+    isa => 'HashRef',
+    lazy => 1,
+    default => sub { +{} },
+    traits => ['Hash'],
+    handles => { _extra_args => 'elements' },
 );
 
 has plugins => (
     isa => ArrayRef[role_type('Dist::Zilla::Role::BuildPL')],
+    init_arg => undef,
     lazy => 1,
     default => sub {
         my $self = shift;
         my %args = (
-            plugin_name => 'ModuleBuildTiny::Fallback',
             zilla => $self->zilla,
-            $self->can('default_jobs') ? ( default_jobs => $self->default_jobs ) : (),
+            $self->_extra_args,
         );
         [
-            Dist::Zilla::Plugin::ModuleBuild->new(%args, mb_version => $self->mb_version),
-            Dist::Zilla::Plugin::ModuleBuildTiny->new(%args, $self->mbt_version ? ( version => $self->mbt_version ) : ()),
+            Dist::Zilla::Plugin::ModuleBuild->new(
+                plugin_name => 'ModuleBuild, via ModuleBuildTiny::Fallback',
+                %args,
+                mb_version => $self->mb_version,
+            ),
+            Dist::Zilla::Plugin::ModuleBuildTiny->new(
+                plugin_name => 'ModuleBuildTiny, via ModuleBuildTiny::Fallback',
+                %args,
+                $self->mbt_version ? ( version => $self->mbt_version ) : (),
+            ),
         ]
     },
     traits => ['Array'],
     handles => { plugins => 'elements' },
 );
 
+around BUILDARGS => sub
+{
+    my $orig = shift;
+    my $self = shift;
+
+    my $args = $self->$orig(@_);
+
+    my %extra_args = %$args;
+    delete @extra_args{qw(version mb_version mbt_version zilla plugin_name)};
+
+    return +{
+        %$args,
+        _extra_args => \%extra_args,
+    };
+};
+
 around dump_config => sub
 {
     my ($orig, $self) = @_;
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
+        mb_version => $self->mb_version,
+        $self->mbt_version ? ( mbt_version => $self->mbt_version ) : (),
         plugins => [
             map {
                 my $plugin = $_;
@@ -351,7 +385,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Modu
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
